from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TaskStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    TASK_STATUS_CREATED: _ClassVar[TaskStatus]
    TASK_STATUS_STARTED: _ClassVar[TaskStatus]
    TASK_STATUS_ABORTED: _ClassVar[TaskStatus]
    TASK_STATUS_FINAL_SUBMISSION: _ClassVar[TaskStatus]
    TASK_STATUS_FINAL_TESTING: _ClassVar[TaskStatus]
    TASK_STATUS_FINAL_DISPUTE: _ClassVar[TaskStatus]
    TASK_STATUS_TERMINATED: _ClassVar[TaskStatus]
TASK_STATUS_CREATED: TaskStatus
TASK_STATUS_STARTED: TaskStatus
TASK_STATUS_ABORTED: TaskStatus
TASK_STATUS_FINAL_SUBMISSION: TaskStatus
TASK_STATUS_FINAL_TESTING: TaskStatus
TASK_STATUS_FINAL_DISPUTE: TaskStatus
TASK_STATUS_TERMINATED: TaskStatus

class Task(_message.Message):
    __slots__ = ("id", "creator", "name", "description", "reward", "duration_in_days", "training_kit", "validation_kit", "final_test_kit", "status", "created_timestamp", "started_timestamp", "terminated_timestamp", "final_submission_timestamp", "final_testing_timestamp", "final_dispute_timestamp", "aborted_timestamp")
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    REWARD_FIELD_NUMBER: _ClassVar[int]
    DURATION_IN_DAYS_FIELD_NUMBER: _ClassVar[int]
    TRAINING_KIT_FIELD_NUMBER: _ClassVar[int]
    VALIDATION_KIT_FIELD_NUMBER: _ClassVar[int]
    FINAL_TEST_KIT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    STARTED_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TERMINATED_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    FINAL_SUBMISSION_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    FINAL_TESTING_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    FINAL_DISPUTE_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    ABORTED_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    id: int
    creator: str
    name: str
    description: str
    reward: int
    duration_in_days: int
    training_kit: str
    validation_kit: str
    final_test_kit: str
    status: TaskStatus
    created_timestamp: int
    started_timestamp: int
    terminated_timestamp: int
    final_submission_timestamp: int
    final_testing_timestamp: int
    final_dispute_timestamp: int
    aborted_timestamp: int
    def __init__(self, id: _Optional[int] = ..., creator: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., reward: _Optional[int] = ..., duration_in_days: _Optional[int] = ..., training_kit: _Optional[str] = ..., validation_kit: _Optional[str] = ..., final_test_kit: _Optional[str] = ..., status: _Optional[_Union[TaskStatus, str]] = ..., created_timestamp: _Optional[int] = ..., started_timestamp: _Optional[int] = ..., terminated_timestamp: _Optional[int] = ..., final_submission_timestamp: _Optional[int] = ..., final_testing_timestamp: _Optional[int] = ..., final_dispute_timestamp: _Optional[int] = ..., aborted_timestamp: _Optional[int] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from ibc.applications.interchain_accounts.controller.v1 import controller_pb2 as _controller_pb2
from ibc.applications.interchain_accounts.host.v1 import host_pb2 as _host_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("controller_genesis_state", "host_genesis_state")
    CONTROLLER_GENESIS_STATE_FIELD_NUMBER: _ClassVar[int]
    HOST_GENESIS_STATE_FIELD_NUMBER: _ClassVar[int]
    controller_genesis_state: ControllerGenesisState
    host_genesis_state: HostGenesisState
    def __init__(self, controller_genesis_state: _Optional[_Union[ControllerGenesisState, _Mapping]] = ..., host_genesis_state: _Optional[_Union[HostGenesisState, _Mapping]] = ...) -> None: ...

class ControllerGenesisState(_message.Message):
    __slots__ = ("active_channels", "interchain_accounts", "ports", "params")
    ACTIVE_CHANNELS_FIELD_NUMBER: _ClassVar[int]
    INTERCHAIN_ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    PORTS_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    active_channels: _containers.RepeatedCompositeFieldContainer[ActiveChannel]
    interchain_accounts: _containers.RepeatedCompositeFieldContainer[RegisteredInterchainAccount]
    ports: _containers.RepeatedScalarFieldContainer[str]
    params: _controller_pb2.Params
    def __init__(self, active_channels: _Optional[_Iterable[_Union[ActiveChannel, _Mapping]]] = ..., interchain_accounts: _Optional[_Iterable[_Union[RegisteredInterchainAccount, _Mapping]]] = ..., ports: _Optional[_Iterable[str]] = ..., params: _Optional[_Union[_controller_pb2.Params, _Mapping]] = ...) -> None: ...

class HostGenesisState(_message.Message):
    __slots__ = ("active_channels", "interchain_accounts", "port", "params")
    ACTIVE_CHANNELS_FIELD_NUMBER: _ClassVar[int]
    INTERCHAIN_ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    active_channels: _containers.RepeatedCompositeFieldContainer[ActiveChannel]
    interchain_accounts: _containers.RepeatedCompositeFieldContainer[RegisteredInterchainAccount]
    port: str
    params: _host_pb2.Params
    def __init__(self, active_channels: _Optional[_Iterable[_Union[ActiveChannel, _Mapping]]] = ..., interchain_accounts: _Optional[_Iterable[_Union[RegisteredInterchainAccount, _Mapping]]] = ..., port: _Optional[str] = ..., params: _Optional[_Union[_host_pb2.Params, _Mapping]] = ...) -> None: ...

class ActiveChannel(_message.Message):
    __slots__ = ("connection_id", "port_id", "channel_id")
    CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    connection_id: str
    port_id: str
    channel_id: str
    def __init__(self, connection_id: _Optional[str] = ..., port_id: _Optional[str] = ..., channel_id: _Optional[str] = ...) -> None: ...

class RegisteredInterchainAccount(_message.Message):
    __slots__ = ("connection_id", "port_id", "account_address")
    CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    ACCOUNT_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    connection_id: str
    port_id: str
    account_address: str
    def __init__(self, connection_id: _Optional[str] = ..., port_id: _Optional[str] = ..., account_address: _Optional[str] = ...) -> None: ...



from amino import amino_pb2 as _amino_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ("min_ion_stake", "max_number_of_slashes", "slash_ratio_percentage", "minimum_reporting_fee", "admin_address", "protocol_surcharge_ratio_percentage", "fee_increase_cooloff_period", "max_fee_increase_ratio_percentage", "stakers_reward_percentage", "pathway_owner_rebate_percentage", "pathway_min_stake")
    MIN_ION_STAKE_FIELD_NUMBER: _ClassVar[int]
    MAX_NUMBER_OF_SLASHES_FIELD_NUMBER: _ClassVar[int]
    SLASH_RATIO_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    MINIMUM_REPORTING_FEE_FIELD_NUMBER: _ClassVar[int]
    ADMIN_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_SURCHARGE_RATIO_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    FEE_INCREASE_COOLOFF_PERIOD_FIELD_NUMBER: _ClassVar[int]
    MAX_FEE_INCREASE_RATIO_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    STAKERS_REWARD_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    PATHWAY_OWNER_REBATE_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    PATHWAY_MIN_STAKE_FIELD_NUMBER: _ClassVar[int]
    min_ion_stake: int
    max_number_of_slashes: int
    slash_ratio_percentage: int
    minimum_reporting_fee: int
    admin_address: str
    protocol_surcharge_ratio_percentage: int
    fee_increase_cooloff_period: int
    max_fee_increase_ratio_percentage: int
    stakers_reward_percentage: int
    pathway_owner_rebate_percentage: int
    pathway_min_stake: int
    def __init__(self, min_ion_stake: _Optional[int] = ..., max_number_of_slashes: _Optional[int] = ..., slash_ratio_percentage: _Optional[int] = ..., minimum_reporting_fee: _Optional[int] = ..., admin_address: _Optional[str] = ..., protocol_surcharge_ratio_percentage: _Optional[int] = ..., fee_increase_cooloff_period: _Optional[int] = ..., max_fee_increase_ratio_percentage: _Optional[int] = ..., stakers_reward_percentage: _Optional[int] = ..., pathway_owner_rebate_percentage: _Optional[int] = ..., pathway_min_stake: _Optional[int] = ...) -> None: ...



from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.auth.v1beta1 import auth_pb2 as _auth_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class InterchainAccount(_message.Message):
    __slots__ = ("base_account", "account_owner")
    BASE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    ACCOUNT_OWNER_FIELD_NUMBER: _ClassVar[int]
    base_account: _auth_pb2.BaseAccount
    account_owner: str
    def __init__(self, base_account: _Optional[_Union[_auth_pb2.BaseAccount, _Mapping]] = ..., account_owner: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from cosmwasm.wasm.v1 import query_pb2 as cosmwasm_dot_wasm_dot_v1_dot_query__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in cosmwasm/wasm/v1/query_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class QueryStub(object):
    """Query provides defines the gRPC querier service
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ContractInfo = channel.unary_unary(
                '/cosmwasm.wasm.v1.Query/ContractInfo',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryContractInfoRequest.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryContractInfoResponse.FromString,
                _registered_method=True)
        self.ContractHistory = channel.unary_unary(
                '/cosmwasm.wasm.v1.Query/ContractHistory',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryContractHistoryRequest.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryContractHistoryResponse.FromString,
                _registered_method=True)
        self.ContractsByCode = channel.unary_unary(
                '/cosmwasm.wasm.v1.Query/ContractsByCode',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryContractsByCodeRequest.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryContractsByCodeResponse.FromString,
                _registered_method=True)
        self.AllContractState = channel.unary_unary(
                '/cosmwasm.wasm.v1.Query/AllContractState',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryAllContractStateRequest.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryAllContractStateResponse.FromString,
                _registered_method=True)
        self.RawContractState = channel.unary_unary(
                '/cosmwasm.wasm.v1.Query/RawContractState',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryRawContractStateRequest.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryRawContractStateResponse.FromString,
                _registered_method=True)
        self.SmartContractState = channel.unary_unary(
                '/cosmwasm.wasm.v1.Query/SmartContractState',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QuerySmartContractStateRequest.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QuerySmartContractStateResponse.FromString,
                _registered_method=True)
        self.Code = channel.unary_unary(
                '/cosmwasm.wasm.v1.Query/Code',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryCodeRequest.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryCodeResponse.FromString,
                _registered_method=True)
        self.Codes = channel.unary_unary(
                '/cosmwasm.wasm.v1.Query/Codes',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryCodesRequest.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryCodesResponse.FromString,
                _registered_method=True)
        self.PinnedCodes = channel.unary_unary(
                '/cosmwasm.wasm.v1.Query/PinnedCodes',
                request_serializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryPinnedCodesRequest.SerializeToString,
                response_deserializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryPinnedCodesResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query provides defines the gRPC querier service
    """

    def ContractInfo(self, request, context):
        """ContractInfo gets the contract meta data
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ContractHistory(self, request, context):
        """ContractHistory gets the contract code history
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ContractsByCode(self, request, context):
        """ContractsByCode lists all smart contracts for a code id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AllContractState(self, request, context):
        """AllContractState gets all raw store data for a single contract
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RawContractState(self, request, context):
        """RawContractState gets single key from the raw store data of a contract
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SmartContractState(self, request, context):
        """SmartContractState get smart query result from the contract
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Code(self, request, context):
        """Code gets the binary code and metadata for a singe wasm code
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Codes(self, request, context):
        """Codes gets the metadata for all stored wasm codes
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PinnedCodes(self, request, context):
        """PinnedCodes gets the pinned code ids
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ContractInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.ContractInfo,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryContractInfoRequest.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryContractInfoResponse.SerializeToString,
            ),
            'ContractHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.ContractHistory,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryContractHistoryRequest.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryContractHistoryResponse.SerializeToString,
            ),
            'ContractsByCode': grpc.unary_unary_rpc_method_handler(
                    servicer.ContractsByCode,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryContractsByCodeRequest.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryContractsByCodeResponse.SerializeToString,
            ),
            'AllContractState': grpc.unary_unary_rpc_method_handler(
                    servicer.AllContractState,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryAllContractStateRequest.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryAllContractStateResponse.SerializeToString,
            ),
            'RawContractState': grpc.unary_unary_rpc_method_handler(
                    servicer.RawContractState,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryRawContractStateRequest.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryRawContractStateResponse.SerializeToString,
            ),
            'SmartContractState': grpc.unary_unary_rpc_method_handler(
                    servicer.SmartContractState,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QuerySmartContractStateRequest.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QuerySmartContractStateResponse.SerializeToString,
            ),
            'Code': grpc.unary_unary_rpc_method_handler(
                    servicer.Code,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryCodeRequest.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryCodeResponse.SerializeToString,
            ),
            'Codes': grpc.unary_unary_rpc_method_handler(
                    servicer.Codes,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryCodesRequest.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryCodesResponse.SerializeToString,
            ),
            'PinnedCodes': grpc.unary_unary_rpc_method_handler(
                    servicer.PinnedCodes,
                    request_deserializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryPinnedCodesRequest.FromString,
                    response_serializer=cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryPinnedCodesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmwasm.wasm.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cosmwasm.wasm.v1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query provides defines the gRPC querier service
    """

    @staticmethod
    def ContractInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Query/ContractInfo',
            cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryContractInfoRequest.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryContractInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ContractHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Query/ContractHistory',
            cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryContractHistoryRequest.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryContractHistoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ContractsByCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Query/ContractsByCode',
            cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryContractsByCodeRequest.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryContractsByCodeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AllContractState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Query/AllContractState',
            cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryAllContractStateRequest.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryAllContractStateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RawContractState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Query/RawContractState',
            cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryRawContractStateRequest.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryRawContractStateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SmartContractState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Query/SmartContractState',
            cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QuerySmartContractStateRequest.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QuerySmartContractStateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Code(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Query/Code',
            cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryCodeRequest.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryCodeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Codes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Query/Codes',
            cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryCodesRequest.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryCodesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PinnedCodes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmwasm.wasm.v1.Query/PinnedCodes',
            cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryPinnedCodesRequest.SerializeToString,
            cosmwasm_dot_wasm_dot_v1_dot_query__pb2.QueryPinnedCodesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/crucible/score_task.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/crucible/score_task.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!neurion/crucible/score_task.proto\x12\x10neurion.crucible\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\x87\x02\n\tScoreTask\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\x15\n\rsubmission_id\x18\x03 \x01(\x04\x12\x17\n\x0fresult_to_check\x18\x04 \x01(\t\x12\x10\n\x08metainfo\x18\x05 \x01(\t\x12\x0e\n\x06scorer\x18\x06 \x01(\t\x12\x19\n\x11\x63reated_timestamp\x18\x07 \x01(\x04\x12\x45\n\x05score\x18\x08 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01\x12\x17\n\x0fscore_timestamp\x18\t \x01(\x04\x12\x10\n\x08task_kit\x18\n \x01(\tB\x1aZ\x18neurion/x/crucible/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.crucible.score_task_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030neurion/x/crucible/types'
  _globals['_SCORETASK'].fields_by_name['score']._loaded_options = None
  _globals['_SCORETASK'].fields_by_name['score']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_SCORETASK']._serialized_start=124
  _globals['_SCORETASK']._serialized_end=387
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/mint/v1beta1/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/mint/v1beta1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.mint.v1beta1 import mint_pb2 as cosmos_dot_mint_dot_v1beta1_dot_mint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/mint/v1beta1/query.proto\x12\x13\x63osmos.mint.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1e\x63osmos/mint/v1beta1/mint.proto\"\x14\n\x12QueryParamsRequest\"H\n\x13QueryParamsResponse\x12\x31\n\x06params\x18\x01 \x01(\x0b\x32\x1b.cosmos.mint.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\"\x17\n\x15QueryInflationRequest\"[\n\x16QueryInflationResponse\x12\x41\n\tinflation\x18\x01 \x01(\x0c\x42.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"\x1e\n\x1cQueryAnnualProvisionsRequest\"j\n\x1dQueryAnnualProvisionsResponse\x12I\n\x11\x61nnual_provisions\x18\x01 \x01(\x0c\x42.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec2\xc5\x03\n\x05Query\x12\x80\x01\n\x06Params\x12\'.cosmos.mint.v1beta1.QueryParamsRequest\x1a(.cosmos.mint.v1beta1.QueryParamsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/mint/v1beta1/params\x12\x8c\x01\n\tInflation\x12*.cosmos.mint.v1beta1.QueryInflationRequest\x1a+.cosmos.mint.v1beta1.QueryInflationResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/cosmos/mint/v1beta1/inflation\x12\xa9\x01\n\x10\x41nnualProvisions\x12\x31.cosmos.mint.v1beta1.QueryAnnualProvisionsRequest\x1a\x32.cosmos.mint.v1beta1.QueryAnnualProvisionsResponse\".\x82\xd3\xe4\x93\x02(\x12&/cosmos/mint/v1beta1/annual_provisionsB+Z)github.com/cosmos/cosmos-sdk/x/mint/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.mint.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/mint/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYINFLATIONRESPONSE'].fields_by_name['inflation']._loaded_options = None
  _globals['_QUERYINFLATIONRESPONSE'].fields_by_name['inflation']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _globals['_QUERYANNUALPROVISIONSRESPONSE'].fields_by_name['annual_provisions']._loaded_options = None
  _globals['_QUERYANNUALPROVISIONSRESPONSE'].fields_by_name['annual_provisions']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\035\022\033/cosmos/mint/v1beta1/params'
  _globals['_QUERY'].methods_by_name['Inflation']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Inflation']._serialized_options = b'\202\323\344\223\002 \022\036/cosmos/mint/v1beta1/inflation'
  _globals['_QUERY'].methods_by_name['AnnualProvisions']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AnnualProvisions']._serialized_options = b'\202\323\344\223\002(\022&/cosmos/mint/v1beta1/annual_provisions'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=140
  _globals['_QUERYPARAMSREQUEST']._serialized_end=160
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=162
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=234
  _globals['_QUERYINFLATIONREQUEST']._serialized_start=236
  _globals['_QUERYINFLATIONREQUEST']._serialized_end=259
  _globals['_QUERYINFLATIONRESPONSE']._serialized_start=261
  _globals['_QUERYINFLATIONRESPONSE']._serialized_end=352
  _globals['_QUERYANNUALPROVISIONSREQUEST']._serialized_start=354
  _globals['_QUERYANNUALPROVISIONSREQUEST']._serialized_end=384
  _globals['_QUERYANNUALPROVISIONSRESPONSE']._serialized_start=386
  _globals['_QUERYANNUALPROVISIONSRESPONSE']._serialized_end=492
  _globals['_QUERY']._serialized_start=495
  _globals['_QUERY']._serialized_end=948
# @@protoc_insertion_point(module_scope)



from google.protobuf import any_pb2 as _any_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.auth.v1beta1 import auth_pb2 as _auth_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("params", "accounts")
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    params: _auth_pb2.Params
    accounts: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    def __init__(self, params: _Optional[_Union[_auth_pb2.Params, _Mapping]] = ..., accounts: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ...) -> None: ...



from typing import Optional

from neurionpy.protos.neurion.fusion.tx_pb2 import (
    MsgUpdateParams,
    MsgUpdateParamsResponse,
    MsgApplyCreator,
    MsgApplyCreatorResponse,
    MsgApproveApplication,
    MsgApproveApplicationResponse,
    MsgRejectApplication,
    MsgRejectApplicationResponse,
    MsgCreateTask,
    MsgCreateTaskResponse,
    MsgStartTask,
    MsgStartTaskResponse,
    MsgProposeModel,
    MsgProposeModelResponse,
    MsgRegisterProposer,
    MsgRegisterProposerResponse,
    MsgRegisterValidator,
    MsgRegisterValidatorResponse,
    MsgStartTesting,
    MsgStartTestingResponse,
    MsgRequestValidationTask,
    MsgRequestValidationTaskResponse,
    MsgSubmitScore,
    MsgSubmitScoreResponse,
    MsgDisputeModelScore,
    MsgDisputeModelScoreResponse,
    MsgStartNewRound,
    MsgStartNewRoundResponse,
    MsgTerminateTask,
    MsgTerminateTaskResponse,
    MsgStakeToTask,
    MsgStakeToTaskResponse,
    MsgClaimTaskReward,
    MsgClaimTaskRewardResponse,
    MsgUnstakeFromTask,
    MsgUnstakeFromTaskResponse,
    MsgDisclaimCreatorStatus,
    MsgDisclaimCreatorStatusResponse,
    MsgAbortTask,
    MsgAbortTaskResponse,
)
from neurionpy.fusion.interface import FusionMessage
from neurionpy.synapse.tx import Transaction
from neurionpy.synapse.tx_helpers import SubmittedTx
from neurionpy.synapse.utils import NeurionUtils
from neurionpy.synapse.wallet import Wallet


class FusionMsgClient(FusionMessage):
    def __init__(self, utils: NeurionUtils, wallet: Optional[Wallet]) -> None:
        """
        Initialize the Fusion message client.

        :param utils: NeurionUtils instance for transaction preparation and broadcasting.
        :param wallet: Wallet instance for signing transactions.
        :raises ValueError: if wallet is not provided.
        """
        if wallet is None:
            raise ValueError("A wallet must be provided to initialize FusionMsgClient.")
        self.utils = utils
        self.wallet = wallet

    def _set_creator(self, message) -> None:
        """
        If the message has a 'creator' field and it is not set, assign it to the wallet's address.
        """
        if hasattr(message, "creator") and not bool(message.creator):
            message.creator = str(self.wallet.address())

    def UpdateParams(
            self,
            message: MsgUpdateParams,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """
        Update module parameters.

        Note: This message uses an 'authority' field, so no creator defaulting is applied.
        """
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def ApplyCreator(
            self,
            message: MsgApplyCreator,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Apply to become a creator."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def ApproveApplication(
            self,
            message: MsgApproveApplication,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Approve a creator application."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def RejectApplication(
            self,
            message: MsgRejectApplication,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Reject a creator application."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def CreateTask(
            self,
            message: MsgCreateTask,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Create a new task."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def StartTask(
            self,
            message: MsgStartTask,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Start a task."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def ProposeModel(
            self,
            message: MsgProposeModel,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Propose a model for a task."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def RegisterProposer(
            self,
            message: MsgRegisterProposer,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Register as a proposer for a task."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def RegisterValidator(
            self,
            message: MsgRegisterValidator,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Register as a validator for a task."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def StartTesting(
            self,
            message: MsgStartTesting,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Start testing for a task."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def RequestValidationTask(
            self,
            message: MsgRequestValidationTask,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Request a validation task."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def SubmitScore(
            self,
            message: MsgSubmitScore,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Submit a score for a validation task."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def DisputeModelScore(
            self,
            message: MsgDisputeModelScore,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Dispute a model score."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def StartNewRound(
            self,
            message: MsgStartNewRound,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Start a new round for a task."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def TerminateTask(
            self,
            message: MsgTerminateTask,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Terminate a task."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def StakeToTask(
            self,
            message: MsgStakeToTask,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Stake tokens to a task."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def ClaimTaskReward(
            self,
            message: MsgClaimTaskReward,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Claim reward for a task."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def UnstakeFromTask(
            self,
            message: MsgUnstakeFromTask,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Unstake tokens from a task."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def DisclaimCreatorStatus(
            self,
            message: MsgDisclaimCreatorStatus,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Disclaim creator status."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def AbortTask(
            self,
            message: MsgAbortTask,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Abort a task."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/privval/v1/types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/privval/v1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cometbft.types.v1 import types_pb2 as cometbft_dot_types_dot_v1_dot_types__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63ometbft/privval/v1/types.proto\x12\x13\x63ometbft.privval.v1\x1a\x1d\x63ometbft/types/v1/types.proto\x1a\x14gogoproto/gogo.proto\"6\n\x11RemoteSignerError\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"!\n\rPubKeyRequest\x12\x10\n\x08\x63hain_id\x18\x01 \x01(\t\"z\n\x0ePubKeyResponse\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32&.cometbft.privval.v1.RemoteSignerError\x12\x15\n\rpub_key_bytes\x18\x03 \x01(\x0c\x12\x14\n\x0cpub_key_type\x18\x04 \x01(\tJ\x04\x08\x01\x10\x02\"j\n\x0fSignVoteRequest\x12%\n\x04vote\x18\x01 \x01(\x0b\x32\x17.cometbft.types.v1.Vote\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\x12\x1e\n\x16skip_extension_signing\x18\x03 \x01(\x08\"x\n\x12SignedVoteResponse\x12+\n\x04vote\x18\x01 \x01(\x0b\x32\x17.cometbft.types.v1.VoteB\x04\xc8\xde\x1f\x00\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32&.cometbft.privval.v1.RemoteSignerError\"V\n\x13SignProposalRequest\x12-\n\x08proposal\x18\x01 \x01(\x0b\x32\x1b.cometbft.types.v1.Proposal\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\"\x84\x01\n\x16SignedProposalResponse\x12\x33\n\x08proposal\x18\x01 \x01(\x0b\x32\x1b.cometbft.types.v1.ProposalB\x04\xc8\xde\x1f\x00\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32&.cometbft.privval.v1.RemoteSignerError\"!\n\x10SignBytesRequest\x12\r\n\x05value\x18\x01 \x01(\x0c\"]\n\x11SignBytesResponse\x12\x11\n\tsignature\x18\x01 \x01(\x0c\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32&.cometbft.privval.v1.RemoteSignerError\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"\xba\x05\n\x07Message\x12=\n\x0fpub_key_request\x18\x01 \x01(\x0b\x32\".cometbft.privval.v1.PubKeyRequestH\x00\x12?\n\x10pub_key_response\x18\x02 \x01(\x0b\x32#.cometbft.privval.v1.PubKeyResponseH\x00\x12\x41\n\x11sign_vote_request\x18\x03 \x01(\x0b\x32$.cometbft.privval.v1.SignVoteRequestH\x00\x12G\n\x14signed_vote_response\x18\x04 \x01(\x0b\x32\'.cometbft.privval.v1.SignedVoteResponseH\x00\x12I\n\x15sign_proposal_request\x18\x05 \x01(\x0b\x32(.cometbft.privval.v1.SignProposalRequestH\x00\x12O\n\x18signed_proposal_response\x18\x06 \x01(\x0b\x32+.cometbft.privval.v1.SignedProposalResponseH\x00\x12\x38\n\x0cping_request\x18\x07 \x01(\x0b\x32 .cometbft.privval.v1.PingRequestH\x00\x12:\n\rping_response\x18\x08 \x01(\x0b\x32!.cometbft.privval.v1.PingResponseH\x00\x12\x43\n\x12sign_bytes_request\x18\t \x01(\x0b\x32%.cometbft.privval.v1.SignBytesRequestH\x00\x12\x45\n\x13sign_bytes_response\x18\n \x01(\x0b\x32&.cometbft.privval.v1.SignBytesResponseH\x00\x42\x05\n\x03sumB6Z4github.com/cometbft/cometbft/api/cometbft/privval/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.privval.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z4github.com/cometbft/cometbft/api/cometbft/privval/v1'
  _globals['_SIGNEDVOTERESPONSE'].fields_by_name['vote']._loaded_options = None
  _globals['_SIGNEDVOTERESPONSE'].fields_by_name['vote']._serialized_options = b'\310\336\037\000'
  _globals['_SIGNEDPROPOSALRESPONSE'].fields_by_name['proposal']._loaded_options = None
  _globals['_SIGNEDPROPOSALRESPONSE'].fields_by_name['proposal']._serialized_options = b'\310\336\037\000'
  _globals['_REMOTESIGNERERROR']._serialized_start=109
  _globals['_REMOTESIGNERERROR']._serialized_end=163
  _globals['_PUBKEYREQUEST']._serialized_start=165
  _globals['_PUBKEYREQUEST']._serialized_end=198
  _globals['_PUBKEYRESPONSE']._serialized_start=200
  _globals['_PUBKEYRESPONSE']._serialized_end=322
  _globals['_SIGNVOTEREQUEST']._serialized_start=324
  _globals['_SIGNVOTEREQUEST']._serialized_end=430
  _globals['_SIGNEDVOTERESPONSE']._serialized_start=432
  _globals['_SIGNEDVOTERESPONSE']._serialized_end=552
  _globals['_SIGNPROPOSALREQUEST']._serialized_start=554
  _globals['_SIGNPROPOSALREQUEST']._serialized_end=640
  _globals['_SIGNEDPROPOSALRESPONSE']._serialized_start=643
  _globals['_SIGNEDPROPOSALRESPONSE']._serialized_end=775
  _globals['_SIGNBYTESREQUEST']._serialized_start=777
  _globals['_SIGNBYTESREQUEST']._serialized_end=810
  _globals['_SIGNBYTESRESPONSE']._serialized_start=812
  _globals['_SIGNBYTESRESPONSE']._serialized_end=905
  _globals['_PINGREQUEST']._serialized_start=907
  _globals['_PINGREQUEST']._serialized_end=920
  _globals['_PINGRESPONSE']._serialized_start=922
  _globals['_PINGRESPONSE']._serialized_end=936
  _globals['_MESSAGE']._serialized_start=939
  _globals['_MESSAGE']._serialized_end=1637
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/base/query/v1beta1/pagination.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/base/query/v1beta1/pagination.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cosmos/base/query/v1beta1/pagination.proto\x12\x19\x63osmos.base.query.v1beta1\"_\n\x0bPageRequest\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x04\x12\x13\n\x0b\x63ount_total\x18\x04 \x01(\x08\x12\x0f\n\x07reverse\x18\x05 \x01(\x08\"/\n\x0cPageResponse\x12\x10\n\x08next_key\x18\x01 \x01(\x0c\x12\r\n\x05total\x18\x02 \x01(\x04\x42*Z(github.com/cosmos/cosmos-sdk/types/queryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.query.v1beta1.pagination_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z(github.com/cosmos/cosmos-sdk/types/query'
  _globals['_PAGEREQUEST']._serialized_start=73
  _globals['_PAGEREQUEST']._serialized_end=168
  _globals['_PAGERESPONSE']._serialized_start=170
  _globals['_PAGERESPONSE']._serialized_end=217
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ConsensusParams(_message.Message):
    __slots__ = ("block", "evidence", "validator", "version", "abci", "synchrony", "feature")
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    ABCI_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONY_FIELD_NUMBER: _ClassVar[int]
    FEATURE_FIELD_NUMBER: _ClassVar[int]
    block: BlockParams
    evidence: EvidenceParams
    validator: ValidatorParams
    version: VersionParams
    abci: ABCIParams
    synchrony: SynchronyParams
    feature: FeatureParams
    def __init__(self, block: _Optional[_Union[BlockParams, _Mapping]] = ..., evidence: _Optional[_Union[EvidenceParams, _Mapping]] = ..., validator: _Optional[_Union[ValidatorParams, _Mapping]] = ..., version: _Optional[_Union[VersionParams, _Mapping]] = ..., abci: _Optional[_Union[ABCIParams, _Mapping]] = ..., synchrony: _Optional[_Union[SynchronyParams, _Mapping]] = ..., feature: _Optional[_Union[FeatureParams, _Mapping]] = ...) -> None: ...

class BlockParams(_message.Message):
    __slots__ = ("max_bytes", "max_gas")
    MAX_BYTES_FIELD_NUMBER: _ClassVar[int]
    MAX_GAS_FIELD_NUMBER: _ClassVar[int]
    max_bytes: int
    max_gas: int
    def __init__(self, max_bytes: _Optional[int] = ..., max_gas: _Optional[int] = ...) -> None: ...

class EvidenceParams(_message.Message):
    __slots__ = ("max_age_num_blocks", "max_age_duration", "max_bytes")
    MAX_AGE_NUM_BLOCKS_FIELD_NUMBER: _ClassVar[int]
    MAX_AGE_DURATION_FIELD_NUMBER: _ClassVar[int]
    MAX_BYTES_FIELD_NUMBER: _ClassVar[int]
    max_age_num_blocks: int
    max_age_duration: _duration_pb2.Duration
    max_bytes: int
    def __init__(self, max_age_num_blocks: _Optional[int] = ..., max_age_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., max_bytes: _Optional[int] = ...) -> None: ...

class ValidatorParams(_message.Message):
    __slots__ = ("pub_key_types",)
    PUB_KEY_TYPES_FIELD_NUMBER: _ClassVar[int]
    pub_key_types: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, pub_key_types: _Optional[_Iterable[str]] = ...) -> None: ...

class VersionParams(_message.Message):
    __slots__ = ("app",)
    APP_FIELD_NUMBER: _ClassVar[int]
    app: int
    def __init__(self, app: _Optional[int] = ...) -> None: ...

class HashedParams(_message.Message):
    __slots__ = ("block_max_bytes", "block_max_gas")
    BLOCK_MAX_BYTES_FIELD_NUMBER: _ClassVar[int]
    BLOCK_MAX_GAS_FIELD_NUMBER: _ClassVar[int]
    block_max_bytes: int
    block_max_gas: int
    def __init__(self, block_max_bytes: _Optional[int] = ..., block_max_gas: _Optional[int] = ...) -> None: ...

class SynchronyParams(_message.Message):
    __slots__ = ("precision", "message_delay")
    PRECISION_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_DELAY_FIELD_NUMBER: _ClassVar[int]
    precision: _duration_pb2.Duration
    message_delay: _duration_pb2.Duration
    def __init__(self, precision: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., message_delay: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class FeatureParams(_message.Message):
    __slots__ = ("vote_extensions_enable_height", "pbts_enable_height")
    VOTE_EXTENSIONS_ENABLE_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PBTS_ENABLE_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    vote_extensions_enable_height: _wrappers_pb2.Int64Value
    pbts_enable_height: _wrappers_pb2.Int64Value
    def __init__(self, vote_extensions_enable_height: _Optional[_Union[_wrappers_pb2.Int64Value, _Mapping]] = ..., pbts_enable_height: _Optional[_Union[_wrappers_pb2.Int64Value, _Mapping]] = ...) -> None: ...

class ABCIParams(_message.Message):
    __slots__ = ("vote_extensions_enable_height",)
    VOTE_EXTENSIONS_ENABLE_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    vote_extensions_enable_height: int
    def __init__(self, vote_extensions_enable_height: _Optional[int] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Metadata(_message.Message):
    __slots__ = ("version", "controller_connection_id", "host_connection_id", "address", "encoding", "tx_type")
    VERSION_FIELD_NUMBER: _ClassVar[int]
    CONTROLLER_CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    HOST_CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ENCODING_FIELD_NUMBER: _ClassVar[int]
    TX_TYPE_FIELD_NUMBER: _ClassVar[int]
    version: str
    controller_connection_id: str
    host_connection_id: str
    address: str
    encoding: str
    tx_type: str
    def __init__(self, version: _Optional[str] = ..., controller_connection_id: _Optional[str] = ..., host_connection_id: _Optional[str] = ..., address: _Optional[str] = ..., encoding: _Optional[str] = ..., tx_type: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/types/v1/canonical.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/types/v1/canonical.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cometbft.types.v1 import types_pb2 as cometbft_dot_types_dot_v1_dot_types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cometbft/types/v1/canonical.proto\x12\x11\x63ometbft.types.v1\x1a\x14gogoproto/gogo.proto\x1a\x1d\x63ometbft/types/v1/types.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"j\n\x10\x43\x61nonicalBlockID\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12H\n\x0fpart_set_header\x18\x02 \x01(\x0b\x32).cometbft.types.v1.CanonicalPartSetHeaderB\x04\xc8\xde\x1f\x00\"5\n\x16\x43\x61nonicalPartSetHeader\x12\r\n\x05total\x18\x01 \x01(\r\x12\x0c\n\x04hash\x18\x02 \x01(\x0c\"\x9f\x02\n\x11\x43\x61nonicalProposal\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .cometbft.types.v1.SignedMsgType\x12\x0e\n\x06height\x18\x02 \x01(\x10\x12\r\n\x05round\x18\x03 \x01(\x10\x12\x1f\n\tpol_round\x18\x04 \x01(\x03\x42\x0c\xe2\xde\x1f\x08POLRound\x12\x42\n\x08\x62lock_id\x18\x05 \x01(\x0b\x32#.cometbft.types.v1.CanonicalBlockIDB\x0b\xe2\xde\x1f\x07\x42lockID\x12\x37\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1d\n\x08\x63hain_id\x18\x07 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainID\"\xfa\x01\n\rCanonicalVote\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .cometbft.types.v1.SignedMsgType\x12\x0e\n\x06height\x18\x02 \x01(\x10\x12\r\n\x05round\x18\x03 \x01(\x10\x12\x42\n\x08\x62lock_id\x18\x04 \x01(\x0b\x32#.cometbft.types.v1.CanonicalBlockIDB\x0b\xe2\xde\x1f\x07\x42lockID\x12\x37\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1d\n\x08\x63hain_id\x18\x06 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainID\"\\\n\x16\x43\x61nonicalVoteExtension\x12\x11\n\textension\x18\x01 \x01(\x0c\x12\x0e\n\x06height\x18\x02 \x01(\x10\x12\r\n\x05round\x18\x03 \x01(\x10\x12\x10\n\x08\x63hain_id\x18\x04 \x01(\tB4Z2github.com/cometbft/cometbft/api/cometbft/types/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.types.v1.canonical_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z2github.com/cometbft/cometbft/api/cometbft/types/v1'
  _globals['_CANONICALBLOCKID'].fields_by_name['part_set_header']._loaded_options = None
  _globals['_CANONICALBLOCKID'].fields_by_name['part_set_header']._serialized_options = b'\310\336\037\000'
  _globals['_CANONICALPROPOSAL'].fields_by_name['pol_round']._loaded_options = None
  _globals['_CANONICALPROPOSAL'].fields_by_name['pol_round']._serialized_options = b'\342\336\037\010POLRound'
  _globals['_CANONICALPROPOSAL'].fields_by_name['block_id']._loaded_options = None
  _globals['_CANONICALPROPOSAL'].fields_by_name['block_id']._serialized_options = b'\342\336\037\007BlockID'
  _globals['_CANONICALPROPOSAL'].fields_by_name['timestamp']._loaded_options = None
  _globals['_CANONICALPROPOSAL'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_CANONICALPROPOSAL'].fields_by_name['chain_id']._loaded_options = None
  _globals['_CANONICALPROPOSAL'].fields_by_name['chain_id']._serialized_options = b'\342\336\037\007ChainID'
  _globals['_CANONICALVOTE'].fields_by_name['block_id']._loaded_options = None
  _globals['_CANONICALVOTE'].fields_by_name['block_id']._serialized_options = b'\342\336\037\007BlockID'
  _globals['_CANONICALVOTE'].fields_by_name['timestamp']._loaded_options = None
  _globals['_CANONICALVOTE'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_CANONICALVOTE'].fields_by_name['chain_id']._loaded_options = None
  _globals['_CANONICALVOTE'].fields_by_name['chain_id']._serialized_options = b'\342\336\037\007ChainID'
  _globals['_CANONICALBLOCKID']._serialized_start=142
  _globals['_CANONICALBLOCKID']._serialized_end=248
  _globals['_CANONICALPARTSETHEADER']._serialized_start=250
  _globals['_CANONICALPARTSETHEADER']._serialized_end=303
  _globals['_CANONICALPROPOSAL']._serialized_start=306
  _globals['_CANONICALPROPOSAL']._serialized_end=593
  _globals['_CANONICALVOTE']._serialized_start=596
  _globals['_CANONICALVOTE']._serialized_end=846
  _globals['_CANONICALVOTEEXTENSION']._serialized_start=848
  _globals['_CANONICALVOTEEXTENSION']._serialized_end=940
# @@protoc_insertion_point(module_scope)



from abc import ABC, abstractmethod

from neurionpy.protos.cosmos.consensus.v1.query_pb2 import QueryParamsRequest, QueryParamsResponse


class Consensus(ABC):
    """Consensus abstract class."""
    @abstractmethod
    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """
        Query the parameters of bank module.

        :param request: QueryParamsRequest

        :return: QueryParamsResponse
        """


from cometbft.types.v2 import block_pb2 as _block_pb2
from cometbft.types.v2 import types_pb2 as _types_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BlockRequest(_message.Message):
    __slots__ = ("height",)
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int
    def __init__(self, height: _Optional[int] = ...) -> None: ...

class NoBlockResponse(_message.Message):
    __slots__ = ("height",)
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int
    def __init__(self, height: _Optional[int] = ...) -> None: ...

class StatusRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class StatusResponse(_message.Message):
    __slots__ = ("height", "base")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    BASE_FIELD_NUMBER: _ClassVar[int]
    height: int
    base: int
    def __init__(self, height: _Optional[int] = ..., base: _Optional[int] = ...) -> None: ...

class BlockResponse(_message.Message):
    __slots__ = ("block", "ext_commit")
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    EXT_COMMIT_FIELD_NUMBER: _ClassVar[int]
    block: _block_pb2.Block
    ext_commit: _types_pb2.ExtendedCommit
    def __init__(self, block: _Optional[_Union[_block_pb2.Block, _Mapping]] = ..., ext_commit: _Optional[_Union[_types_pb2.ExtendedCommit, _Mapping]] = ...) -> None: ...

class Message(_message.Message):
    __slots__ = ("block_request", "no_block_response", "block_response", "status_request", "status_response")
    BLOCK_REQUEST_FIELD_NUMBER: _ClassVar[int]
    NO_BLOCK_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    BLOCK_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    STATUS_REQUEST_FIELD_NUMBER: _ClassVar[int]
    STATUS_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    block_request: BlockRequest
    no_block_response: NoBlockResponse
    block_response: BlockResponse
    status_request: StatusRequest
    status_response: StatusResponse
    def __init__(self, block_request: _Optional[_Union[BlockRequest, _Mapping]] = ..., no_block_response: _Optional[_Union[NoBlockResponse, _Mapping]] = ..., block_response: _Optional[_Union[BlockResponse, _Mapping]] = ..., status_request: _Optional[_Union[StatusRequest, _Mapping]] = ..., status_response: _Optional[_Union[StatusResponse, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/crucible/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/crucible/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from neurion.crucible import params_pb2 as neurion_dot_crucible_dot_params__pb2
from neurion.crucible import task_pb2 as neurion_dot_crucible_dot_task__pb2
from neurion.crucible import submission_pb2 as neurion_dot_crucible_dot_submission__pb2
from neurion.crucible import plagiarism_report_pb2 as neurion_dot_crucible_dot_plagiarism__report__pb2
from neurion.crucible import creator_application_pb2 as neurion_dot_crucible_dot_creator__application__pb2
from neurion.crucible import score_task_pb2 as neurion_dot_crucible_dot_score__task__pb2
from neurion.crucible import error_code_pb2 as neurion_dot_crucible_dot_error__code__pb2
from neurion.crucible import dispute_score_task_pb2 as neurion_dot_crucible_dot_dispute__score__task__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cneurion/crucible/query.proto\x12\x10neurion.crucible\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1dneurion/crucible/params.proto\x1a\x1bneurion/crucible/task.proto\x1a!neurion/crucible/submission.proto\x1a(neurion/crucible/plagiarism_report.proto\x1a*neurion/crucible/creator_application.proto\x1a!neurion/crucible/score_task.proto\x1a!neurion/crucible/error_code.proto\x1a)neurion/crucible/dispute_score_task.proto\"\x14\n\x12QueryParamsRequest\"J\n\x13QueryParamsResponse\x12\x33\n\x06params\x18\x01 \x01(\x0b\x32\x18.neurion.crucible.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x19\n\x17QueryGetCreatorsRequest\",\n\x18QueryGetCreatorsResponse\x12\x10\n\x08\x63reators\x18\x01 \x03(\t\"5\n\"QueryGetCreatorApplicationsRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\"l\n#QueryGetCreatorApplicationsResponse\x12\x45\n\x0c\x61pplications\x18\x01 \x03(\x0b\x32$.neurion.crucible.CreatorApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"!\n\x13QueryGetTaskRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"G\n\x14QueryGetTaskResponse\x12/\n\x04task\x18\x01 \x01(\x0b\x32\x16.neurion.crucible.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"9\n\x18QueryListAllTasksRequest\x12\x0e\n\x06offset\x18\x01 \x01(\x04\x12\r\n\x05limit\x18\x02 \x01(\x04\"\x8a\x01\n\x19QueryListAllTasksResponse\x12\x30\n\x05tasks\x18\x01 \x03(\x0b\x32\x16.neurion.crucible.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"l\n\x1dQueryListTasksByStatusRequest\x12,\n\x06status\x18\x01 \x01(\x0e\x32\x1c.neurion.crucible.TaskStatus\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x04\"\x8f\x01\n\x1eQueryListTasksByStatusResponse\x12\x30\n\x05tasks\x18\x01 \x03(\x0b\x32\x16.neurion.crucible.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\'\n\x19QueryGetSubmissionRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"Y\n\x1aQueryGetSubmissionResponse\x12;\n\nsubmission\x18\x01 \x01(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"J\n&QueryGetSubmissionByTaskCreatorRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\"\xb7\x01\n\'QueryGetSubmissionByTaskCreatorResponse\x12\x42\n\x11\x66inal_submissions\x18\x01 \x03(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12H\n\x17provisional_submissions\x18\x02 \x03(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"2\n\x1fQueryGetSubmissionByTaskRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\"\xb0\x01\n QueryGetSubmissionByTaskResponse\x12\x42\n\x11\x66inal_submissions\x18\x01 \x03(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12H\n\x17provisional_submissions\x18\x02 \x03(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"J\n(QueryGetEncryptedProofOfOwnershipRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x11\n\tplaintext\x18\x02 \x01(\t\"?\n)QueryGetEncryptedProofOfOwnershipResponse\x12\x12\n\nciphertext\x18\x01 \x01(\t\"4\n\x1fQueryGetPlagiarismReportRequest\x12\x11\n\treport_id\x18\x01 \x01(\x04\"a\n QueryGetPlagiarismReportResponse\x12=\n\x06report\x18\x01 \x01(\x0b\x32\".neurion.crucible.PlagiarismReportB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\":\n\x19QueryGetTaskRewardRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\x0c\n\x04user\x18\x02 \x01(\t\",\n\x1aQueryGetTaskRewardResponse\x12\x0e\n\x06reward\x18\x01 \x01(\x04\"+\n)QueryGetPendingCreatorApplicationsRequest\"q\n*QueryGetPendingCreatorApplicationsResponse\x12\x43\n\napplicants\x18\x01 \x03(\x0b\x32$.neurion.crucible.CreatorApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"9\n\x18QueryGetTaskStakeRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\x0c\n\x04user\x18\x02 \x01(\t\"*\n\x19QueryGetTaskStakeResponse\x12\r\n\x05stake\x18\x01 \x01(\x04\";\n(QueryGetUnscoredSubmissionsByTaskRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\"i\n)QueryGetUnscoredSubmissionsByTaskResponse\x12<\n\x0bsubmissions\x18\x01 \x03(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"I\n%QueryCanTriggerFinalSubmissionRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"e\n&QueryCanTriggerFinalSubmissionResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12+\n\x06reason\x18\x02 \x01(\x0e\x32\x1b.neurion.crucible.ErrorCode\"F\n\"QueryCanTriggerFinalTestingRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"b\n#QueryCanTriggerFinalTestingResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12+\n\x06reason\x18\x02 \x01(\x0e\x32\x1b.neurion.crucible.ErrorCode\"A\n QueryCanRegisterAsTrainerRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"`\n!QueryCanRegisterAsTrainerResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12+\n\x06reason\x18\x02 \x01(\x0e\x32\x1b.neurion.crucible.ErrorCode\"@\n\x1fQueryCanRegisterAsScorerRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"_\n QueryCanRegisterAsScorerResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12+\n\x06reason\x18\x02 \x01(\x0e\x32\x1b.neurion.crucible.ErrorCode\"6\n\x15QueryIsTrainerRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"U\n\x16QueryIsTrainerResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12+\n\x06reason\x18\x02 \x01(\x0e\x32\x1b.neurion.crucible.ErrorCode\"5\n\x14QueryIsScorerRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"T\n\x15QueryIsScorerResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12+\n\x06reason\x18\x02 \x01(\x0e\x32\x1b.neurion.crucible.ErrorCode\"D\n#QueryCanSubmitTrainingResultRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"c\n$QueryCanSubmitTrainingResultResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12+\n\x06reason\x18\x02 \x01(\x0e\x32\x1b.neurion.crucible.ErrorCode\"A\n QueryCanSubmitFinalResultRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"`\n!QueryCanSubmitFinalResultResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12+\n\x06reason\x18\x02 \x01(\x0e\x32\x1b.neurion.crucible.ErrorCode\"B\n!QueryCanRequestScoringTaskRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"a\n\"QueryCanRequestScoringTaskResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12+\n\x06reason\x18\x02 \x01(\x0e\x32\x1b.neurion.crucible.ErrorCode\"C\n\"QueryGetPendingScoringTasksRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"b\n#QueryGetPendingScoringTasksResponse\x12;\n\x0bscore_tasks\x18\x01 \x03(\x0b\x32\x1b.neurion.crucible.ScoreTaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"<\n\x18QueryCanTerminateRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"X\n\x19QueryCanTerminateResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12+\n\x06reason\x18\x02 \x01(\x0e\x32\x1b.neurion.crucible.ErrorCode\"7\n\'QueryGetPlagiarismReportFromUserRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\"u\n(QueryGetPlagiarismReportFromUserResponse\x12I\n\x12plagiarism_reports\x18\x01 \x03(\x0b\x32\".neurion.crucible.PlagiarismReportB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"3\n#QueryGetScoreDisputeFromUserRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\"r\n$QueryGetScoreDisputeFromUserResponse\x12J\n\x13\x64ispute_score_tasks\x18\x01 \x03(\x0b\x32\".neurion.crucible.DisputeScoreTaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x32\x80)\n\x05Query\x12w\n\x06Params\x12$.neurion.crucible.QueryParamsRequest\x1a%.neurion.crucible.QueryParamsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/neurion/crucible/params\x12\x8c\x01\n\x0bGetCreators\x12).neurion.crucible.QueryGetCreatorsRequest\x1a*.neurion.crucible.QueryGetCreatorsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/neurion/crucible/get_creators\x12\xc3\x01\n\x16GetCreatorApplications\x12\x34.neurion.crucible.QueryGetCreatorApplicationsRequest\x1a\x35.neurion.crucible.QueryGetCreatorApplicationsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/neurion/crucible/get_creator_applications/{creator}\x12\x81\x01\n\x07GetTask\x12%.neurion.crucible.QueryGetTaskRequest\x1a&.neurion.crucible.QueryGetTaskResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/neurion/crucible/get_task/{id}\x12\xa2\x01\n\x0cListAllTasks\x12*.neurion.crucible.QueryListAllTasksRequest\x1a+.neurion.crucible.QueryListAllTasksResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/neurion/crucible/list_all_tasks/{offset}/{limit}\x12\xc0\x01\n\x11ListTasksByStatus\x12/.neurion.crucible.QueryListTasksByStatusRequest\x1a\x30.neurion.crucible.QueryListTasksByStatusResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/neurion/crucible/list_tasks_by_status/{status}/{offset}/{limit}\x12\x99\x01\n\rGetSubmission\x12+.neurion.crucible.QueryGetSubmissionRequest\x1a,.neurion.crucible.QueryGetSubmissionResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/neurion/crucible/get_submission/{id}\x12\xdf\x01\n\x1aGetSubmissionByTaskCreator\x12\x38.neurion.crucible.QueryGetSubmissionByTaskCreatorRequest\x1a\x39.neurion.crucible.QueryGetSubmissionByTaskCreatorResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/neurion/crucible/get_submission_by_task_creator/{task_id}/{creator}\x12\xb8\x01\n\x13GetSubmissionByTask\x12\x31.neurion.crucible.QueryGetSubmissionByTaskRequest\x1a\x32.neurion.crucible.QueryGetSubmissionByTaskResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/crucible/get_submission_by_task/{task_id}\x12\xe5\x01\n\x1cGetEncryptedProofOfOwnership\x12:.neurion.crucible.QueryGetEncryptedProofOfOwnershipRequest\x1a;.neurion.crucible.QueryGetEncryptedProofOfOwnershipResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/neurion/crucible/get_encrypted_proof_of_ownership/{key}/{plaintext}\x12\xb9\x01\n\x13GetPlagiarismReport\x12\x31.neurion.crucible.QueryGetPlagiarismReportRequest\x1a\x32.neurion.crucible.QueryGetPlagiarismReportResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/neurion/crucible/get_plagiarism_report/{report_id}\x12\xa6\x01\n\rGetTaskReward\x12+.neurion.crucible.QueryGetTaskRewardRequest\x1a,.neurion.crucible.QueryGetTaskRewardResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/crucible/get_task_reward/{task_id}/{user}\x12\xd6\x01\n\x1dGetPendingCreatorApplications\x12;.neurion.crucible.QueryGetPendingCreatorApplicationsRequest\x1a<.neurion.crucible.QueryGetPendingCreatorApplicationsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/crucible/get_pending_creator_applications\x12\xa2\x01\n\x0cGetTaskStake\x12*.neurion.crucible.QueryGetTaskStakeRequest\x1a+.neurion.crucible.QueryGetTaskStakeResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/neurion/crucible/get_task_stake/{task_id}/{user}\x12\xdd\x01\n\x1cGetUnscoredSubmissionsByTask\x12:.neurion.crucible.QueryGetUnscoredSubmissionsByTaskRequest\x1a;.neurion.crucible.QueryGetUnscoredSubmissionsByTaskResponse\"D\x82\xd3\xe4\x93\x02>\x12</neurion/crucible/get_unscored_submissions_by_task/{task_id}\x12\xda\x01\n\x19\x43\x61nTriggerFinalSubmission\x12\x37.neurion.crucible.QueryCanTriggerFinalSubmissionRequest\x1a\x38.neurion.crucible.QueryCanTriggerFinalSubmissionResponse\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/neurion/crucible/can_trigger_final_submission/{creator}/{task_id}\x12\xce\x01\n\x16\x43\x61nTriggerFinalTesting\x12\x34.neurion.crucible.QueryCanTriggerFinalTestingRequest\x1a\x35.neurion.crucible.QueryCanTriggerFinalTestingResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/neurion/crucible/can_trigger_final_testing/{creator}/{task_id}\x12\xc3\x01\n\x14\x43\x61nRegisterAsTrainer\x12\x32.neurion.crucible.QueryCanRegisterAsTrainerRequest\x1a\x33.neurion.crucible.QueryCanRegisterAsTrainerResponse\"B\x82\xd3\xe4\x93\x02<\x12:/neurion/crucible/can_register_as_trainer/{user}/{task_id}\x12\xbf\x01\n\x13\x43\x61nRegisterAsScorer\x12\x31.neurion.crucible.QueryCanRegisterAsScorerRequest\x1a\x32.neurion.crucible.QueryCanRegisterAsScorerResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/neurion/crucible/can_register_as_scorer/{user}/{task_id}\x12\x95\x01\n\tIsTrainer\x12\'.neurion.crucible.QueryIsTrainerRequest\x1a(.neurion.crucible.QueryIsTrainerResponse\"5\x82\xd3\xe4\x93\x02/\x12-/neurion/crucible/is_trainer/{user}/{task_id}\x12\x91\x01\n\x08IsScorer\x12&.neurion.crucible.QueryIsScorerRequest\x1a\'.neurion.crucible.QueryIsScorerResponse\"4\x82\xd3\xe4\x93\x02.\x12,/neurion/crucible/is_scorer/{user}/{task_id}\x12\xcf\x01\n\x17\x43\x61nSubmitTrainingResult\x12\x35.neurion.crucible.QueryCanSubmitTrainingResultRequest\x1a\x36.neurion.crucible.QueryCanSubmitTrainingResultResponse\"E\x82\xd3\xe4\x93\x02?\x12=/neurion/crucible/can_submit_training_result/{user}/{task_id}\x12\xc3\x01\n\x14\x43\x61nSubmitFinalResult\x12\x32.neurion.crucible.QueryCanSubmitFinalResultRequest\x1a\x33.neurion.crucible.QueryCanSubmitFinalResultResponse\"B\x82\xd3\xe4\x93\x02<\x12:/neurion/crucible/can_submit_final_result/{user}/{task_id}\x12\xc7\x01\n\x15\x43\x61nRequestScoringTask\x12\x33.neurion.crucible.QueryCanRequestScoringTaskRequest\x1a\x34.neurion.crucible.QueryCanRequestScoringTaskResponse\"C\x82\xd3\xe4\x93\x02=\x12;/neurion/crucible/can_request_scoring_task/{user}/{task_id}\x12\xcb\x01\n\x16GetPendingScoringTasks\x12\x34.neurion.crucible.QueryGetPendingScoringTasksRequest\x1a\x35.neurion.crucible.QueryGetPendingScoringTasksResponse\"D\x82\xd3\xe4\x93\x02>\x12</neurion/crucible/get_pending_scoring_tasks/{user}/{task_id}\x12\xa4\x01\n\x0c\x43\x61nTerminate\x12*.neurion.crucible.QueryCanTerminateRequest\x1a+.neurion.crucible.QueryCanTerminateResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/neurion/crucible/can_terminate/{creator}/{task_id}\x12\xd6\x01\n\x1bGetPlagiarismReportFromUser\x12\x39.neurion.crucible.QueryGetPlagiarismReportFromUserRequest\x1a:.neurion.crucible.QueryGetPlagiarismReportFromUserResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/neurion/crucible/get_plagiarism_report_from_user/{user}\x12\xc6\x01\n\x17GetScoreDisputeFromUser\x12\x35.neurion.crucible.QueryGetScoreDisputeFromUserRequest\x1a\x36.neurion.crucible.QueryGetScoreDisputeFromUserResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/neurion/crucible/get_score_dispute_from_user/{user}B\x1aZ\x18neurion/x/crucible/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.crucible.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030neurion/x/crucible/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE'].fields_by_name['applications']._loaded_options = None
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE'].fields_by_name['applications']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETTASKRESPONSE'].fields_by_name['task']._loaded_options = None
  _globals['_QUERYGETTASKRESPONSE'].fields_by_name['task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYLISTALLTASKSRESPONSE'].fields_by_name['tasks']._loaded_options = None
  _globals['_QUERYLISTALLTASKSRESPONSE'].fields_by_name['tasks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYLISTTASKSBYSTATUSRESPONSE'].fields_by_name['tasks']._loaded_options = None
  _globals['_QUERYLISTTASKSBYSTATUSRESPONSE'].fields_by_name['tasks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSUBMISSIONRESPONSE'].fields_by_name['submission']._loaded_options = None
  _globals['_QUERYGETSUBMISSIONRESPONSE'].fields_by_name['submission']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE'].fields_by_name['final_submissions']._loaded_options = None
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE'].fields_by_name['final_submissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE'].fields_by_name['provisional_submissions']._loaded_options = None
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE'].fields_by_name['provisional_submissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE'].fields_by_name['final_submissions']._loaded_options = None
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE'].fields_by_name['final_submissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE'].fields_by_name['provisional_submissions']._loaded_options = None
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE'].fields_by_name['provisional_submissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPLAGIARISMREPORTRESPONSE'].fields_by_name['report']._loaded_options = None
  _globals['_QUERYGETPLAGIARISMREPORTRESPONSE'].fields_by_name['report']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE'].fields_by_name['applicants']._loaded_options = None
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE'].fields_by_name['applicants']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKRESPONSE'].fields_by_name['submissions']._loaded_options = None
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKRESPONSE'].fields_by_name['submissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPENDINGSCORINGTASKSRESPONSE'].fields_by_name['score_tasks']._loaded_options = None
  _globals['_QUERYGETPENDINGSCORINGTASKSRESPONSE'].fields_by_name['score_tasks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPLAGIARISMREPORTFROMUSERRESPONSE'].fields_by_name['plagiarism_reports']._loaded_options = None
  _globals['_QUERYGETPLAGIARISMREPORTFROMUSERRESPONSE'].fields_by_name['plagiarism_reports']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSCOREDISPUTEFROMUSERRESPONSE'].fields_by_name['dispute_score_tasks']._loaded_options = None
  _globals['_QUERYGETSCOREDISPUTEFROMUSERRESPONSE'].fields_by_name['dispute_score_tasks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\032\022\030/neurion/crucible/params'
  _globals['_QUERY'].methods_by_name['GetCreators']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetCreators']._serialized_options = b'\202\323\344\223\002 \022\036/neurion/crucible/get_creators'
  _globals['_QUERY'].methods_by_name['GetCreatorApplications']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetCreatorApplications']._serialized_options = b'\202\323\344\223\0026\0224/neurion/crucible/get_creator_applications/{creator}'
  _globals['_QUERY'].methods_by_name['GetTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTask']._serialized_options = b'\202\323\344\223\002!\022\037/neurion/crucible/get_task/{id}'
  _globals['_QUERY'].methods_by_name['ListAllTasks']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ListAllTasks']._serialized_options = b'\202\323\344\223\0023\0221/neurion/crucible/list_all_tasks/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['ListTasksByStatus']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ListTasksByStatus']._serialized_options = b'\202\323\344\223\002B\022@/neurion/crucible/list_tasks_by_status/{status}/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['GetSubmission']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetSubmission']._serialized_options = b'\202\323\344\223\002\'\022%/neurion/crucible/get_submission/{id}'
  _globals['_QUERY'].methods_by_name['GetSubmissionByTaskCreator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetSubmissionByTaskCreator']._serialized_options = b'\202\323\344\223\002F\022D/neurion/crucible/get_submission_by_task_creator/{task_id}/{creator}'
  _globals['_QUERY'].methods_by_name['GetSubmissionByTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetSubmissionByTask']._serialized_options = b'\202\323\344\223\0024\0222/neurion/crucible/get_submission_by_task/{task_id}'
  _globals['_QUERY'].methods_by_name['GetEncryptedProofOfOwnership']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetEncryptedProofOfOwnership']._serialized_options = b'\202\323\344\223\002F\022D/neurion/crucible/get_encrypted_proof_of_ownership/{key}/{plaintext}'
  _globals['_QUERY'].methods_by_name['GetPlagiarismReport']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPlagiarismReport']._serialized_options = b'\202\323\344\223\0025\0223/neurion/crucible/get_plagiarism_report/{report_id}'
  _globals['_QUERY'].methods_by_name['GetTaskReward']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTaskReward']._serialized_options = b'\202\323\344\223\0024\0222/neurion/crucible/get_task_reward/{task_id}/{user}'
  _globals['_QUERY'].methods_by_name['GetPendingCreatorApplications']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPendingCreatorApplications']._serialized_options = b'\202\323\344\223\0024\0222/neurion/crucible/get_pending_creator_applications'
  _globals['_QUERY'].methods_by_name['GetTaskStake']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTaskStake']._serialized_options = b'\202\323\344\223\0023\0221/neurion/crucible/get_task_stake/{task_id}/{user}'
  _globals['_QUERY'].methods_by_name['GetUnscoredSubmissionsByTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetUnscoredSubmissionsByTask']._serialized_options = b'\202\323\344\223\002>\022</neurion/crucible/get_unscored_submissions_by_task/{task_id}'
  _globals['_QUERY'].methods_by_name['CanTriggerFinalSubmission']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanTriggerFinalSubmission']._serialized_options = b'\202\323\344\223\002D\022B/neurion/crucible/can_trigger_final_submission/{creator}/{task_id}'
  _globals['_QUERY'].methods_by_name['CanTriggerFinalTesting']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanTriggerFinalTesting']._serialized_options = b'\202\323\344\223\002A\022?/neurion/crucible/can_trigger_final_testing/{creator}/{task_id}'
  _globals['_QUERY'].methods_by_name['CanRegisterAsTrainer']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanRegisterAsTrainer']._serialized_options = b'\202\323\344\223\002<\022:/neurion/crucible/can_register_as_trainer/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['CanRegisterAsScorer']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanRegisterAsScorer']._serialized_options = b'\202\323\344\223\002;\0229/neurion/crucible/can_register_as_scorer/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['IsTrainer']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IsTrainer']._serialized_options = b'\202\323\344\223\002/\022-/neurion/crucible/is_trainer/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['IsScorer']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IsScorer']._serialized_options = b'\202\323\344\223\002.\022,/neurion/crucible/is_scorer/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['CanSubmitTrainingResult']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanSubmitTrainingResult']._serialized_options = b'\202\323\344\223\002?\022=/neurion/crucible/can_submit_training_result/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['CanSubmitFinalResult']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanSubmitFinalResult']._serialized_options = b'\202\323\344\223\002<\022:/neurion/crucible/can_submit_final_result/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['CanRequestScoringTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanRequestScoringTask']._serialized_options = b'\202\323\344\223\002=\022;/neurion/crucible/can_request_scoring_task/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['GetPendingScoringTasks']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPendingScoringTasks']._serialized_options = b'\202\323\344\223\002>\022</neurion/crucible/get_pending_scoring_tasks/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['CanTerminate']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanTerminate']._serialized_options = b'\202\323\344\223\0025\0223/neurion/crucible/can_terminate/{creator}/{task_id}'
  _globals['_QUERY'].methods_by_name['GetPlagiarismReportFromUser']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPlagiarismReportFromUser']._serialized_options = b'\202\323\344\223\002:\0228/neurion/crucible/get_plagiarism_report_from_user/{user}'
  _globals['_QUERY'].methods_by_name['GetScoreDisputeFromUser']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetScoreDisputeFromUser']._serialized_options = b'\202\323\344\223\0026\0224/neurion/crucible/get_score_dispute_from_user/{user}'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=459
  _globals['_QUERYPARAMSREQUEST']._serialized_end=479
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=481
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=555
  _globals['_QUERYGETCREATORSREQUEST']._serialized_start=557
  _globals['_QUERYGETCREATORSREQUEST']._serialized_end=582
  _globals['_QUERYGETCREATORSRESPONSE']._serialized_start=584
  _globals['_QUERYGETCREATORSRESPONSE']._serialized_end=628
  _globals['_QUERYGETCREATORAPPLICATIONSREQUEST']._serialized_start=630
  _globals['_QUERYGETCREATORAPPLICATIONSREQUEST']._serialized_end=683
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE']._serialized_start=685
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE']._serialized_end=793
  _globals['_QUERYGETTASKREQUEST']._serialized_start=795
  _globals['_QUERYGETTASKREQUEST']._serialized_end=828
  _globals['_QUERYGETTASKRESPONSE']._serialized_start=830
  _globals['_QUERYGETTASKRESPONSE']._serialized_end=901
  _globals['_QUERYLISTALLTASKSREQUEST']._serialized_start=903
  _globals['_QUERYLISTALLTASKSREQUEST']._serialized_end=960
  _globals['_QUERYLISTALLTASKSRESPONSE']._serialized_start=963
  _globals['_QUERYLISTALLTASKSRESPONSE']._serialized_end=1101
  _globals['_QUERYLISTTASKSBYSTATUSREQUEST']._serialized_start=1103
  _globals['_QUERYLISTTASKSBYSTATUSREQUEST']._serialized_end=1211
  _globals['_QUERYLISTTASKSBYSTATUSRESPONSE']._serialized_start=1214
  _globals['_QUERYLISTTASKSBYSTATUSRESPONSE']._serialized_end=1357
  _globals['_QUERYGETSUBMISSIONREQUEST']._serialized_start=1359
  _globals['_QUERYGETSUBMISSIONREQUEST']._serialized_end=1398
  _globals['_QUERYGETSUBMISSIONRESPONSE']._serialized_start=1400
  _globals['_QUERYGETSUBMISSIONRESPONSE']._serialized_end=1489
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORREQUEST']._serialized_start=1491
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORREQUEST']._serialized_end=1565
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE']._serialized_start=1568
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE']._serialized_end=1751
  _globals['_QUERYGETSUBMISSIONBYTASKREQUEST']._serialized_start=1753
  _globals['_QUERYGETSUBMISSIONBYTASKREQUEST']._serialized_end=1803
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE']._serialized_start=1806
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE']._serialized_end=1982
  _globals['_QUERYGETENCRYPTEDPROOFOFOWNERSHIPREQUEST']._serialized_start=1984
  _globals['_QUERYGETENCRYPTEDPROOFOFOWNERSHIPREQUEST']._serialized_end=2058
  _globals['_QUERYGETENCRYPTEDPROOFOFOWNERSHIPRESPONSE']._serialized_start=2060
  _globals['_QUERYGETENCRYPTEDPROOFOFOWNERSHIPRESPONSE']._serialized_end=2123
  _globals['_QUERYGETPLAGIARISMREPORTREQUEST']._serialized_start=2125
  _globals['_QUERYGETPLAGIARISMREPORTREQUEST']._serialized_end=2177
  _globals['_QUERYGETPLAGIARISMREPORTRESPONSE']._serialized_start=2179
  _globals['_QUERYGETPLAGIARISMREPORTRESPONSE']._serialized_end=2276
  _globals['_QUERYGETTASKREWARDREQUEST']._serialized_start=2278
  _globals['_QUERYGETTASKREWARDREQUEST']._serialized_end=2336
  _globals['_QUERYGETTASKREWARDRESPONSE']._serialized_start=2338
  _globals['_QUERYGETTASKREWARDRESPONSE']._serialized_end=2382
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSREQUEST']._serialized_start=2384
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSREQUEST']._serialized_end=2427
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE']._serialized_start=2429
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE']._serialized_end=2542
  _globals['_QUERYGETTASKSTAKEREQUEST']._serialized_start=2544
  _globals['_QUERYGETTASKSTAKEREQUEST']._serialized_end=2601
  _globals['_QUERYGETTASKSTAKERESPONSE']._serialized_start=2603
  _globals['_QUERYGETTASKSTAKERESPONSE']._serialized_end=2645
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKREQUEST']._serialized_start=2647
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKREQUEST']._serialized_end=2706
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKRESPONSE']._serialized_start=2708
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKRESPONSE']._serialized_end=2813
  _globals['_QUERYCANTRIGGERFINALSUBMISSIONREQUEST']._serialized_start=2815
  _globals['_QUERYCANTRIGGERFINALSUBMISSIONREQUEST']._serialized_end=2888
  _globals['_QUERYCANTRIGGERFINALSUBMISSIONRESPONSE']._serialized_start=2890
  _globals['_QUERYCANTRIGGERFINALSUBMISSIONRESPONSE']._serialized_end=2991
  _globals['_QUERYCANTRIGGERFINALTESTINGREQUEST']._serialized_start=2993
  _globals['_QUERYCANTRIGGERFINALTESTINGREQUEST']._serialized_end=3063
  _globals['_QUERYCANTRIGGERFINALTESTINGRESPONSE']._serialized_start=3065
  _globals['_QUERYCANTRIGGERFINALTESTINGRESPONSE']._serialized_end=3163
  _globals['_QUERYCANREGISTERASTRAINERREQUEST']._serialized_start=3165
  _globals['_QUERYCANREGISTERASTRAINERREQUEST']._serialized_end=3230
  _globals['_QUERYCANREGISTERASTRAINERRESPONSE']._serialized_start=3232
  _globals['_QUERYCANREGISTERASTRAINERRESPONSE']._serialized_end=3328
  _globals['_QUERYCANREGISTERASSCORERREQUEST']._serialized_start=3330
  _globals['_QUERYCANREGISTERASSCORERREQUEST']._serialized_end=3394
  _globals['_QUERYCANREGISTERASSCORERRESPONSE']._serialized_start=3396
  _globals['_QUERYCANREGISTERASSCORERRESPONSE']._serialized_end=3491
  _globals['_QUERYISTRAINERREQUEST']._serialized_start=3493
  _globals['_QUERYISTRAINERREQUEST']._serialized_end=3547
  _globals['_QUERYISTRAINERRESPONSE']._serialized_start=3549
  _globals['_QUERYISTRAINERRESPONSE']._serialized_end=3634
  _globals['_QUERYISSCORERREQUEST']._serialized_start=3636
  _globals['_QUERYISSCORERREQUEST']._serialized_end=3689
  _globals['_QUERYISSCORERRESPONSE']._serialized_start=3691
  _globals['_QUERYISSCORERRESPONSE']._serialized_end=3775
  _globals['_QUERYCANSUBMITTRAININGRESULTREQUEST']._serialized_start=3777
  _globals['_QUERYCANSUBMITTRAININGRESULTREQUEST']._serialized_end=3845
  _globals['_QUERYCANSUBMITTRAININGRESULTRESPONSE']._serialized_start=3847
  _globals['_QUERYCANSUBMITTRAININGRESULTRESPONSE']._serialized_end=3946
  _globals['_QUERYCANSUBMITFINALRESULTREQUEST']._serialized_start=3948
  _globals['_QUERYCANSUBMITFINALRESULTREQUEST']._serialized_end=4013
  _globals['_QUERYCANSUBMITFINALRESULTRESPONSE']._serialized_start=4015
  _globals['_QUERYCANSUBMITFINALRESULTRESPONSE']._serialized_end=4111
  _globals['_QUERYCANREQUESTSCORINGTASKREQUEST']._serialized_start=4113
  _globals['_QUERYCANREQUESTSCORINGTASKREQUEST']._serialized_end=4179
  _globals['_QUERYCANREQUESTSCORINGTASKRESPONSE']._serialized_start=4181
  _globals['_QUERYCANREQUESTSCORINGTASKRESPONSE']._serialized_end=4278
  _globals['_QUERYGETPENDINGSCORINGTASKSREQUEST']._serialized_start=4280
  _globals['_QUERYGETPENDINGSCORINGTASKSREQUEST']._serialized_end=4347
  _globals['_QUERYGETPENDINGSCORINGTASKSRESPONSE']._serialized_start=4349
  _globals['_QUERYGETPENDINGSCORINGTASKSRESPONSE']._serialized_end=4447
  _globals['_QUERYCANTERMINATEREQUEST']._serialized_start=4449
  _globals['_QUERYCANTERMINATEREQUEST']._serialized_end=4509
  _globals['_QUERYCANTERMINATERESPONSE']._serialized_start=4511
  _globals['_QUERYCANTERMINATERESPONSE']._serialized_end=4599
  _globals['_QUERYGETPLAGIARISMREPORTFROMUSERREQUEST']._serialized_start=4601
  _globals['_QUERYGETPLAGIARISMREPORTFROMUSERREQUEST']._serialized_end=4656
  _globals['_QUERYGETPLAGIARISMREPORTFROMUSERRESPONSE']._serialized_start=4658
  _globals['_QUERYGETPLAGIARISMREPORTFROMUSERRESPONSE']._serialized_end=4775
  _globals['_QUERYGETSCOREDISPUTEFROMUSERREQUEST']._serialized_start=4777
  _globals['_QUERYGETSCOREDISPUTEFROMUSERREQUEST']._serialized_end=4828
  _globals['_QUERYGETSCOREDISPUTEFROMUSERRESPONSE']._serialized_start=4830
  _globals['_QUERYGETSCOREDISPUTEFROMUSERRESPONSE']._serialized_end=4944
  _globals['_QUERY']._serialized_start=4947
  _globals['_QUERY']._serialized_end=10195
# @@protoc_insertion_point(module_scope)



import hashlib

from Crypto.Hash import RIPEMD160  # type: ignore # nosec


def sha256(contents: bytes) -> bytes:
    """
    Get sha256 hash.

    :param contents: bytes contents.

    :return: bytes sha256 hash.
    """
    h = hashlib.sha256()
    h.update(contents)
    return h.digest()


def ripemd160(contents: bytes) -> bytes:
    """
    Get ripemd160 hash using PyCryptodome.

    :param contents: bytes contents.

    :return: bytes ripemd160 hash.
    """
    h = RIPEMD160.new()
    h.update(contents)
    return h.digest()



from google.protobuf.json_format import Parse

from neurionpy.common.rest_client import RestClient
from neurionpy.consensus.interface import Consensus
from neurionpy.protos.cosmos.consensus.v1.query_pb2 import QueryParamsRequest, QueryParamsResponse


class ConsensusRestClient(Consensus):
    """Bank REST client."""

    API_URL = "/cosmos/consensus/v1"

    def __init__(self, rest_api: RestClient):
        """
        Create bank rest client.

        :param rest_api: RestClient api
        """
        self._rest_api = rest_api

    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """
        Query the parameters of bank module.

        :param request: QueryParamsRequest

        :return: QueryParamsResponse
        """
        response = self._rest_api.get(f"{self.API_URL}/params")
        return Parse(response, QueryParamsResponse())


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/rpc/grpc/v1beta2/types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/rpc/grpc/v1beta2/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cometbft.rpc.grpc.v1beta1 import types_pb2 as cometbft_dot_rpc_dot_grpc_dot_v1beta1_dot_types__pb2
from cometbft.abci.v1beta2 import types_pb2 as cometbft_dot_abci_dot_v1beta2_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cometbft/rpc/grpc/v1beta2/types.proto\x12\x19\x63ometbft.rpc.grpc.v1beta2\x1a%cometbft/rpc/grpc/v1beta1/types.proto\x1a!cometbft/abci/v1beta2/types.proto\"\x8d\x01\n\x13ResponseBroadcastTx\x12\x38\n\x08\x63heck_tx\x18\x01 \x01(\x0b\x32&.cometbft.abci.v1beta2.ResponseCheckTx\x12<\n\ndeliver_tx\x18\x02 \x01(\x0b\x32(.cometbft.abci.v1beta2.ResponseDeliverTx2\xd5\x01\n\x0c\x42roadcastAPI\x12W\n\x04Ping\x12&.cometbft.rpc.grpc.v1beta1.RequestPing\x1a\'.cometbft.rpc.grpc.v1beta1.ResponsePing\x12l\n\x0b\x42roadcastTx\x12-.cometbft.rpc.grpc.v1beta1.RequestBroadcastTx\x1a..cometbft.rpc.grpc.v1beta2.ResponseBroadcastTxB<Z:github.com/cometbft/cometbft/api/cometbft/rpc/grpc/v1beta2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.rpc.grpc.v1beta2.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/cometbft/cometbft/api/cometbft/rpc/grpc/v1beta2'
  _globals['_RESPONSEBROADCASTTX']._serialized_start=143
  _globals['_RESPONSEBROADCASTTX']._serialized_end=284
  _globals['_BROADCASTAPI']._serialized_start=287
  _globals['_BROADCASTAPI']._serialized_end=500
# @@protoc_insertion_point(module_scope)



from abc import ABC, abstractmethod
from typing import Optional

from neurionpy.protos.neurion.fusion.tx_pb2 import (
    MsgUpdateParams, MsgUpdateParamsResponse,
    MsgApplyCreator, MsgApplyCreatorResponse,
    MsgApproveApplication, MsgApproveApplicationResponse,
    MsgRejectApplication, MsgRejectApplicationResponse,
    MsgCreateTask, MsgCreateTaskResponse,
    MsgStartTask, MsgStartTaskResponse,
    MsgProposeModel, MsgProposeModelResponse,
    MsgRegisterProposer, MsgRegisterProposerResponse,
    MsgRegisterValidator, MsgRegisterValidatorResponse,
    MsgStartTesting, MsgStartTestingResponse,
    MsgRequestValidationTask, MsgRequestValidationTaskResponse,
    MsgSubmitScore, MsgSubmitScoreResponse,
    MsgDisputeModelScore, MsgDisputeModelScoreResponse,
    MsgStartNewRound, MsgStartNewRoundResponse,
    MsgTerminateTask, MsgTerminateTaskResponse,
    MsgStakeToTask, MsgStakeToTaskResponse,
    MsgClaimTaskReward, MsgClaimTaskRewardResponse,
    MsgUnstakeFromTask, MsgUnstakeFromTaskResponse,
    MsgDisclaimCreatorStatus, MsgDisclaimCreatorStatusResponse,
    MsgAbortTask, MsgAbortTaskResponse,
)

from neurionpy.protos.neurion.fusion.query_pb2 import (
    QueryParamsRequest, QueryParamsResponse,
    QueryGetTaskRequest, QueryGetTaskResponse,
    QueryGetTaskRewardRequest, QueryGetTaskRewardResponse,
    QueryGetCreatorApplicationsRequest, QueryGetCreatorApplicationsResponse,
    QueryGetPendingCreatorApplicationsRequest, QueryGetPendingCreatorApplicationsResponse,
    QueryGetModelsByRoundRequest, QueryGetModelsByRoundResponse,
    QueryGetTaskStakeRequest, QueryGetTaskStakeResponse,
    QueryGetValidationTaskRequest, QueryGetValidationTaskResponse,
    QueryCanTriggerTestingForRoundRequest, QueryCanTriggerTestingForRoundResponse,
    QueryCanStartNewRoundRequest, QueryCanStartNewRoundResponse,
    QueryCanRegisterAsProposerRequest, QueryCanRegisterAsProposerResponse,
    QueryCanRegisterAsValidatorRequest, QueryCanRegisterAsValidatorResponse,
    QueryIsProposerRequest, QueryIsProposerResponse,
    QueryIsValidatorRequest, QueryIsValidatorResponse,
    QueryCanProposeModelRequest, QueryCanProposeModelResponse,
    QueryCanRequestValidationTaskRequest, QueryCanRequestValidationTaskResponse,
    QueryGetPendingValidationTasksRequest, QueryGetPendingValidationTasksResponse,
    QueryCanTerminateRequest, QueryCanTerminateResponse, QueryGetScoreDisputeFromUserRequest,
    QueryGetScoreDisputeFromUserResponse
)
from neurionpy.synapse.tx_helpers import SubmittedTx


class FusionQuery(ABC):
    """FusionQuery defines the interface for querying data in the Fusion module."""

    @abstractmethod
    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """Query module parameters."""

    @abstractmethod
    def GetTask(self, request: QueryGetTaskRequest) -> QueryGetTaskResponse:
        """Query a task by its ID."""

    @abstractmethod
    def GetTaskReward(self, request: QueryGetTaskRewardRequest) -> QueryGetTaskRewardResponse:
        """Query task reward for a given task and user."""

    @abstractmethod
    def GetCreatorApplications(self, request: QueryGetCreatorApplicationsRequest) -> QueryGetCreatorApplicationsResponse:
        """Query creator applications for a given creator."""

    @abstractmethod
    def GetPendingCreatorApplications(self, request: QueryGetPendingCreatorApplicationsRequest) -> QueryGetPendingCreatorApplicationsResponse:
        """Query pending creator applications."""

    @abstractmethod
    def GetModelsByRound(self, request: QueryGetModelsByRoundRequest) -> QueryGetModelsByRoundResponse:
        """Query proposed models for a given task and round."""

    @abstractmethod
    def GetTaskStake(self, request: QueryGetTaskStakeRequest) -> QueryGetTaskStakeResponse:
        """Query task stake for a given task and user."""

    @abstractmethod
    def GetValidationTask(self, request: QueryGetValidationTaskRequest) -> QueryGetValidationTaskResponse:
        """Query a validation task by its ID."""

    @abstractmethod
    def CanTriggerTestingForRound(self, request: QueryCanTriggerTestingForRoundRequest) -> QueryCanTriggerTestingForRoundResponse:
        """Check if a user can trigger testing for a specific round."""

    @abstractmethod
    def CanStartNewRound(self, request: QueryCanStartNewRoundRequest) -> QueryCanStartNewRoundResponse:
        """Check if a user can start a new round."""

    @abstractmethod
    def CanRegisterAsProposer(self, request: QueryCanRegisterAsProposerRequest) -> QueryCanRegisterAsProposerResponse:
        """Check if a user can register as a proposer."""

    @abstractmethod
    def CanRegisterAsValidator(self, request: QueryCanRegisterAsValidatorRequest) -> QueryCanRegisterAsValidatorResponse:
        """Check if a user can register as a validator."""

    @abstractmethod
    def IsProposer(self, request: QueryIsProposerRequest) -> QueryIsProposerResponse:
        """Check if a user is a proposer for a task."""

    @abstractmethod
    def IsValidator(self, request: QueryIsValidatorRequest) -> QueryIsValidatorResponse:
        """Check if a user is a validator for a task."""

    @abstractmethod
    def CanProposeModel(self, request: QueryCanProposeModelRequest) -> QueryCanProposeModelResponse:
        """Check if a user can propose a model."""

    @abstractmethod
    def CanRequestValidationTask(self, request: QueryCanRequestValidationTaskRequest) -> QueryCanRequestValidationTaskResponse:
        """Check if a user can request a validation task."""

    @abstractmethod
    def GetPendingValidationTasks(self, request: QueryGetPendingValidationTasksRequest) -> QueryGetPendingValidationTasksResponse:
        """Query pending validation tasks for a user and task."""

    @abstractmethod
    def CanTerminate(self, request: QueryCanTerminateRequest) -> QueryCanTerminateResponse:
        """Check if a task can be terminated by the creator."""

    @abstractmethod
    def GetScoreDisputeFromUser(self, request: QueryGetScoreDisputeFromUserRequest) -> QueryGetScoreDisputeFromUserResponse:
        """Queries a list of score disputes raised by a user."""


class FusionMessage(ABC):
    """FusionMessage defines the interface for executing transactions in the Fusion module."""

    @abstractmethod
    def UpdateParams(self, message: MsgUpdateParams, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Update module parameters."""

    @abstractmethod
    def ApplyCreator(self, message: MsgApplyCreator, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Apply to become a creator."""

    @abstractmethod
    def ApproveApplication(self, message: MsgApproveApplication, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Approve a creator application."""

    @abstractmethod
    def RejectApplication(self, message: MsgRejectApplication, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Reject a creator application."""

    @abstractmethod
    def CreateTask(self, message: MsgCreateTask, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Create a new task."""

    @abstractmethod
    def StartTask(self, message: MsgStartTask, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Start a task."""

    @abstractmethod
    def ProposeModel(self, message: MsgProposeModel, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Propose a model for a task."""

    @abstractmethod
    def RegisterProposer(self, message: MsgRegisterProposer, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Register as a proposer for a task."""

    @abstractmethod
    def RegisterValidator(self, message: MsgRegisterValidator, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Register as a validator for a task."""

    @abstractmethod
    def StartTesting(self, message: MsgStartTesting, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Start testing for a task."""

    @abstractmethod
    def RequestValidationTask(self, message: MsgRequestValidationTask, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Request a validation task."""

    @abstractmethod
    def SubmitScore(self, message: MsgSubmitScore, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Submit a score for a validation task."""

    @abstractmethod
    def DisputeModelScore(self, message: MsgDisputeModelScore, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Dispute a model score."""

    @abstractmethod
    def StartNewRound(self, message: MsgStartNewRound, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Start a new round for a task."""

    @abstractmethod
    def TerminateTask(self, message: MsgTerminateTask, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Terminate a task."""

    @abstractmethod
    def StakeToTask(self, message: MsgStakeToTask, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Stake tokens to a task."""

    @abstractmethod
    def ClaimTaskReward(self, message: MsgClaimTaskReward, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Claim reward for a task."""

    @abstractmethod
    def UnstakeFromTask(self, message: MsgUnstakeFromTask, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Unstake tokens from a task."""

    @abstractmethod
    def DisclaimCreatorStatus(self, message: MsgDisclaimCreatorStatus, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Disclaim creator status."""

    @abstractmethod
    def AbortTask(self, message: MsgAbortTask, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Abort a task."""

